@@ -63,47 +63,36 @@ class BaseHandler(tornado.web.RequestHandler):
 class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
                                tornado.auth.GoogleOAuth2Mixin):
     async def get(self):
-        if self.get_argument('code', False):
-            user = await self.get_authenticated_user(
-                redirect_uri='http://grader-dev.data8x.berkeley.edu',
-                code=self.get_argument('code'))
-            # Save the user with e.g. set_secure_cookie
-            self.set_secure_cookie("user", user)
-        else:
-            self.authorize_redirect(
-                redirect_uri='http://grader-dev.data8x.berkeley.edu',
-                client_id=self.settings['google_oauth']['key'],
-                scope=["profile","email"],
-                response_type='code',
-                extra_params={'approval_prompt': 'auto'})
-
-class LoginHandler(BaseHandler):
-    def get(self):
-        self.write('<html><body><form action="/login" method="post">'
-                   'Name: <input type="text" name="name">'
-                   'Password: <input type="password" name="password">'
-                   '<input type="submit" value="Sign in">'
-                   '</form></body></html>')
-
-    async def post(self):
-        # TODO: salt and hash the password before storing in the DB, then salt
-        # and hash the user's input password before comparing.
-        username = self.get_argument("name")
-        password = self.get_argument("password")
-
-        if password is not None:
-            self.set_secure_cookie("user", username)
-            self.redirect("/")
-        else:
-            # No such user or wrong password.
-            self.redirect("/login")
+        log.write_logs("3. and 5.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        log.write_logs("3. and 5.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')    
+        self.authorize_redirect(
+            redirect_uri='http://grader-dev.data8x.berkeley.edu',
+            client_id=self.settings['google_oauth']['key'],
+            scope=["profile","email"],
+            response_type='code',
+            extra_params={'approval_prompt': 'auto'})
 
 class Userform(tornado.web.RequestHandler):
-    def get(self):
-        if not self.current_user:
+    async def get(self):
+        log.write_logs("1a.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        log.write_logs("1b.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        if self.get_argument('code', False) and not self.get_current_user():
+            log.write_logs("2.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
             self.redirect("/login")
-            return
-        self.render("index.html",  message=None)
+        elif self.get_argument('code', False):
+            log.write_logs("4.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+            user = await self.get_authenticated_user(
+                            redirect_uri='http://grader-dev.data8x.berkeley.edu',
+                            code=self.get_argument('code'))
+            # Save the user with e.g. set_secure_cookie
+            log.write_logs("5.", str(user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+            self.set_secure_cookie("user", user)
+        
+        if self.get_current_user():
+            log.write_logs("6.", "Authenticated!", "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+            self.render("index.html",  message=None)
+
+            
 
 class Download(tornado.web.RequestHandler):
     async def post(self):
@@ -180,7 +169,6 @@ settings = {
 }
 application = tornado.web.Application([
         (r"/", Userform),
-        (r"/glogin", LoginHandler),
         (r"/login", GoogleOAuth2LoginHandler),
         (r"/upload", Upload),
         (r"/download", Download),
